from setuptools import setup, find_packages
setup(name="MemoryCache",
      version="0.2",
      py_modules=["memorycache"],
      install_requires=['typing;python_version<="2.7"'],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)
